@@ -121,6 +121,7 @@ class BinaryEmulator(MemoryManager):
         self.keep_memory_on_free = config.get('keep_memory_on_free', False)
 
         self.network_config = config.get('network', {})
+        self.network_adapters = self.network_config.get('adapters', [])
         self.command_line = config.get('command_line', '')
 
     def get_emu_version(self):
@@ -162,7 +163,7 @@ class BinaryEmulator(MemoryManager):
 
     def get_user(self):
         """
-        Get the current emulated user's name
+        Get the current emulated user properties
         """
         return self.user_config
 
@@ -207,6 +208,12 @@ class BinaryEmulator(MemoryManager):
         """
         return self.network_config
 
+    def get_network_adapters(self):
+        """
+        Get the network adapters specified in the network section of the config file
+        """
+        return self.network_adapters
+
     def get_filesystem_config(self):
         """
         Get the filesystem settings specified in the filesystem section of the config file
