@@ -10,6 +10,7 @@ import speakeasy.winenv.defs.nt.ddk as ddk
 import speakeasy.winenv.defs.registry.reg as regdefs
 import speakeasy.winenv.defs.windows.windows as windefs
 import speakeasy.winenv.defs.nt.ntoskrnl as ntos
+from speakeasy.const import FILE_OPEN, FILE_WRITE, FILE_READ, MEM_WRITE
 from speakeasy.errors import ApiEmuError
 from speakeasy.winenv.api import api
 
@@ -1377,7 +1378,7 @@ class Ntoskrnl(api.ApiHandler):
         else:
             rv = ddk.STATUS_INVALID_PARAMETER
 
-        self.log_process_event(obj, 'mem_write', base=lpBaseAddress,
+        self.log_process_event(obj, MEM_WRITE, base=lpBaseAddress,
                                size=nSize, data=data)
 
         return rv
@@ -2731,7 +2732,7 @@ class Ntoskrnl(api.ApiHandler):
         if obj:
             hnd = self.get_object_handle(obj)
             self.mem_write(pHndl, hnd.to_bytes(self.ptr_size, 'little'))
-            self.log_file_access(name, 'open', disposition=cd, access=ad)
+            self.log_file_access(name, FILE_OPEN, disposition=cd, access=ad)
 
         else:
 
@@ -2765,7 +2766,7 @@ class Ntoskrnl(api.ApiHandler):
                     hfile = self.file_open(npath, create=True)
 
             self.mem_write(pHndl, hfile.to_bytes(self.ptr_size, 'little'))
-            self.log_file_access(npath, 'open', disposition=cd, access=ad)
+            self.log_file_access(npath, FILE_OPEN, disposition=cd, access=ad)
 
         return nts
 
@@ -2809,7 +2810,7 @@ class Ntoskrnl(api.ApiHandler):
             if hfile:
                 nts = ddk.STATUS_SUCCESS
 
-        self.log_file_access(path, 'open', disposition=None, access=ad)
+        self.log_file_access(path, FILE_OPEN, disposition=None, access=ad)
 
         if hfile:
             self.mem_write(pHndl, hfile.to_bytes(self.ptr_size, 'little'))
@@ -2924,7 +2925,7 @@ class Ntoskrnl(api.ApiHandler):
             if data:
                 _file.add_data(data)
                 # Log the file event
-                self.log_file_access(path, 'write', data=data, size=length)
+                self.log_file_access(path, FILE_WRITE, data=data, size=length)
 
                 # Is it ascii?
                 try:
@@ -2966,7 +2967,7 @@ class Ntoskrnl(api.ApiHandler):
                 self.mem_write(buf, data[:length])
 
             # Log the file event
-            self.log_file_access(path, 'read', buffer=buf, size=length)
+            self.log_file_access(path, FILE_READ, buffer=buf, size=length)
 
             nts = ddk.STATUS_SUCCESS
 
