@@ -7,6 +7,7 @@ import speakeasy.winenv.defs.windows.windows as windefs
 import speakeasy.winenv.defs.windows.kernel32 as k32
 import speakeasy.winenv.defs.windows.advapi32 as adv32
 import speakeasy.windows.objman as objman
+from speakeasy.const import PROC_CREATE, REG_OPEN, REG_READ, REG_LIST, REG_CREATE
 
 from .. import api
 from Crypto.Cipher import ARC4
@@ -83,7 +84,7 @@ class AdvApi32(api.ApiHandler):
             if not hnd:
                 rv = windefs.ERROR_PATH_NOT_FOUND
 
-            self.log_registry_access(lpSubKey, 'open_key', handle=hnd)
+            self.log_registry_access(lpSubKey, REG_OPEN, handle=hnd)
 
         if phkResult and hnd:
             self.mem_write(phkResult, hnd.to_bytes(self.get_ptr_size(), 'little'))
@@ -127,7 +128,7 @@ class AdvApi32(api.ApiHandler):
             if not hnd:
                 rv = windefs.ERROR_PATH_NOT_FOUND
 
-            self.log_registry_access(lpSubKey, 'open_key', handle=hnd)
+            self.log_registry_access(lpSubKey, REG_OPEN, handle=hnd)
 
         if phkResult and hnd:
             self.mem_write(phkResult, hnd.to_bytes(self.get_ptr_size(), 'little'))
@@ -197,7 +198,7 @@ class AdvApi32(api.ApiHandler):
                 rv = windefs.ERROR_SUCCESS
 
             kp = key.get_path()
-            self.log_registry_access(kp, 'read_value', value_name=lpValueName, size=length,
+            self.log_registry_access(kp, REG_READ, value_name=lpValueName, size=length,
                                      buffer=lpData)
 
         return rv
@@ -276,7 +277,7 @@ class AdvApi32(api.ApiHandler):
                             name = name.encode('utf-8')
                         self.mem_write(lpName, name)
                         rv = windefs.ERROR_SUCCESS
-            self.log_registry_access(key.get_path(), "list_subkeys")
+            self.log_registry_access(key.get_path(), REG_LIST)
         return rv
 
     @apihook('RegCreateKey', argc=3)
@@ -302,7 +303,7 @@ class AdvApi32(api.ApiHandler):
                     argv[1] = lpSubKey
                     sub_key_path = key.get_path() + '\\' + lpSubKey
                     self.emu.reg_create_key(sub_key_path)
-                    self.log_registry_access(sub_key_path, "create_key")
+                    self.log_registry_access(sub_key_path, REG_CREATE)
                 else:
                     hkey = (hkey).to_bytes(self.get_ptr_size(), 'little')
                     self.mem_write(phkResult, hkey)
@@ -918,6 +919,18 @@ class AdvApi32(api.ApiHandler):
 
         return rv
 
+    @apihook('GetSidIdentifierAuthority', argc=1)
+    def GetSidIdentifierAuthority(self, emu, argv, ctx={}):
+        '''
+        PSID_IDENTIFIER_AUTHORITY GetSidIdentifierAuthority(
+          [in] PSID pSid
+        );
+        '''
+        sid, = argv
+
+        # IdentifierAuthority is at offset 0x02 in the SID structure
+        return sid + 2
+
     @apihook('GetSidSubAuthorityCount', argc=1)
     def GetSidSubAuthorityCount(self, emu, argv, ctx={}):
         '''
@@ -933,6 +946,93 @@ class AdvApi32(api.ApiHandler):
 
         return rv
 
+    @apihook('GetSidSubAuthority', argc=2)
+    def GetSidSubAuthority(self, emu, argv, ctx={}):
+        '''
+        PDWORD GetSidSubAuthority(
+          [in] PSID  pSid,
+          [in] DWORD nSubAuthority
+        );
+        '''
+        sid, nsub = argv
+
+        # SubAuthorities begin at offset 0x8
+        return sid + 8 + (nsub * 4)
+
+    @apihook('LookupAccountName', argc=7)
+    def LookupAccountName(self, emu, argv, ctx={}):
+        '''
+        BOOL LookupAccountNameA(
+          [in, optional]  LPCSTR        lpSystemName,
+          [in]            LPCSTR        lpAccountName,
+          [out, optional] PSID          Sid,
+          [in, out]       LPDWORD       cbSid,
+          [out, optional] LPSTR         ReferencedDomainName,
+          [in, out]       LPDWORD       cchReferencedDomainName,
+          [out]           PSID_NAME_USE peUse
+        );
+        '''
+
+        ptr_sysname, ptr_acctname, ptr_sid, ptr_cbsid, ptr_domname, ptr_cchdomname, ptr_peuse = argv
+        rv = 0
+
+        cw = self.get_char_width(ctx)
+
+        if ptr_sysname:
+            sn = self.read_mem_string(ptr_sysname, cw)
+            argv[0] = sn
+
+        if not ptr_acctname:
+            return rv
+
+        acctname = self.read_mem_string(ptr_acctname, cw)
+        argv[1] = acctname
+
+        user = emu.get_user().get('name')
+        # Currently only supporting user SIDs specified in the config
+        if user != acctname:
+            return rv
+
+        str_sid = emu.get_user().get('sid')
+        if not str_sid:
+            return rv
+
+        argv[2] = str_sid
+        sid_struct = windefs.convert_sid_str_to_struct(emu.get_ptr_size(), str_sid)
+        side_struct_size = sid_struct.sizeof()
+
+        cbsid = self.mem_read(ptr_cbsid, 4)
+        cbsid = int.from_bytes(cbsid, 'little')
+        argv[3] = cbsid
+        if not cbsid:
+            self.mem_write(ptr_cbsid, side_struct_size.to_bytes(4, 'little'))
+            return rv
+
+        if cbsid < side_struct_size:
+            return rv
+
+        domain = emu.get_domain()
+        cchdomname = self.mem_read(ptr_cchdomname, 4)
+        cbcchdomname = int.from_bytes(cchdomname, 'little')
+        argv[5] = cbcchdomname
+        if not cbcchdomname:
+            buf_size = len(domain) + 1
+            self.mem_write(ptr_cchdomname, buf_size.to_bytes(4, 'little'))
+            return rv
+
+        rv = 1
+
+        self.mem_write(ptr_sid, self.get_bytes(sid_struct))
+
+        self.write_mem_string(domain, ptr_domname, cw)
+        argv[4] = domain
+
+        # Currently only supporting user SIDs (SidTypeUser = 1)
+        self.mem_write(ptr_peuse, (1).to_bytes(4, 'little'))
+        argv[6] = 1
+
+        return rv
+
     @apihook('LookupAccountSid', argc=7)
     def LookupAccountSid(self, emu, argv, ctx={}):
         '''
@@ -1018,7 +1118,7 @@ class AdvApi32(api.ApiHandler):
 
         rv = 1
 
-        self.log_process_event(proc, 'create')
+        self.log_process_event(proc, PROC_CREATE)
         return rv
 
     @apihook('CryptCreateHash', argc=5)
@@ -1265,7 +1365,7 @@ class AdvApi32(api.ApiHandler):
                 rv = windefs.ERROR_SUCCESS
 
             kp = key.get_path()
-            self.log_registry_access(kp, 'read_value', value_name=lpValue, size=length,
+            self.log_registry_access(kp, REG_READ, value_name=lpValue, size=length,
                                      buffer=lpData)
 
         return rv
