@@ -126,10 +126,12 @@ class Msvcrt(api.ApiHandler):
             else:
                 if count == _TRUNCATE:
                     self.mem_write(wcstr, ws[:(sizeInWords - 1) * 2])
-                    self.mem_write(pReturnValue, struct.pack("<I",sizeInWords))
+                    if pReturnValue:
+                        self.mem_write(pReturnValue, struct.pack("<I",sizeInWords))
                 else:
                     self.mem_write(wcstr, ws[:count * 2])
-                    self.mem_write(pReturnValue, struct.pack("<I",count + 1))
+                    if pReturnValue:
+                        self.mem_write(pReturnValue, struct.pack("<I",count + 1))
 
         return rv
 
@@ -769,6 +771,23 @@ class Msvcrt(api.ApiHandler):
         argv[1] = s
         return dest
 
+    @apihook('wcsncpy', argc=3, conv=e_arch.CALL_CONV_CDECL)
+    def wcsncpy(self, emu, argv, ctx={}):
+        """
+        wchar_t *wcsncpy(
+           wchar_t *strDest,
+           const wchar_t *strSource,
+           size_t count
+        );
+        """
+        dest, src, count = argv
+        ws = self.read_wide_string(src, max_chars=count)
+        if len(ws) < count:
+            ws += '\x00'*(count-len(ws))
+        self.write_wide_string(ws, dest)
+        argv[1] = ws
+        return dest
+
     @apihook('memcpy', argc=3, conv=e_arch.CALL_CONV_CDECL)
     def memcpy(self, emu, argv, ctx={}):
         """
