@@ -55,12 +55,13 @@ class User32(api.ApiHandler):
         return hnd
 
     def find_string_resource_by_id(self, pe, uID):
-        for entry in pe.DIRECTORY_ENTRY_RESOURCE.entries:
-            if entry.id == 6:  # "String Table"
-                for str_entry in entry.directory.entries:
-                    s = str_entry.directory.strings.get(uID, None)
-                    if s is not None:
-                        return s
+        if hasattr(pe, 'DIRECTORY_ENTRY_RESOURCE'):
+            for entry in pe.DIRECTORY_ENTRY_RESOURCE.entries:
+                if entry.id == 6:  # "String Table"
+                    for str_entry in entry.directory.entries:
+                        s = str_entry.directory.strings.get(uID, None)
+                        if s is not None:
+                            return s
         return None
 
     @apihook('GetDesktopWindow', argc=0)
@@ -300,6 +301,19 @@ class User32(api.ApiHandler):
         hnd = self.sessman.create_window(wn, cn)
         return hnd
 
+    @apihook('SetLayeredWindowAttributes', argc=4)
+    def SetLayeredWindowAttributes(self, emu, argv, ctx={}):
+        '''
+        BOOL SetLayeredWindowAttributes(
+          [in] HWND     hwnd,
+          [in] COLORREF crKey,
+          [in] BYTE     bAlpha,
+          [in] DWORD    dwFlags
+        );
+        '''
+        hwnd, crKey, bAlpha, dwFlags = argv
+        return 1
+
     @apihook('MessageBox', argc=4)
     def MessageBox(self, emu, argv, ctx={}):
         '''int MessageBox(
@@ -407,6 +421,21 @@ class User32(api.ApiHandler):
         rv = 0
         return rv
 
+    @apihook('GetAsyncKeyState', argc=1)
+    def GetAsyncKeyState(self, emu, argv, ctx={}):
+        '''
+        SHORT GetAsyncKeyState(
+          [in] int vKey
+        );
+        '''
+
+        # From MS docs:
+        # If the most significant bit is set, the key is down, 
+        # and if the least significant bit is set, the key was 
+        # pressed after the previous call to GetAsyncKeyState
+
+        return 0
+
     @apihook('GetKeyboardType', argc=1)
     def GetKeyboardType(self, emu, argv, ctx={}):
         '''
@@ -448,6 +477,16 @@ class User32(api.ApiHandler):
         rv = self.get_handle()
         return rv
 
+    @apihook('GetClientRect', argc=2)
+    def GetClientRect(self, emu, argv, ctx={}):
+        """
+        BOOL GetClientRect(
+          [in]  HWND   hWnd,
+          [out] LPRECT lpRect
+        );
+        """
+        return 0
+
     @apihook('RegisterWindowMessage', argc=1)
     def RegisterWindowMessage(self, emu, argv, ctx={}):
         '''
@@ -1248,3 +1287,114 @@ class User32(api.ApiHandler):
         self.mem_write(lpList + 4, locale.to_bytes(2, 'little'))
 
         return 1
+
+    @apihook("GetKBCodePage", argc=0)
+    def GetKBCodePage(self, emu, argv, ctx={}):
+        '''
+        INT GetKBCodePage();
+        '''
+        # >>> ctypes.windll.user32.GetKBCodePage()
+        # 437
+        # https://docs.microsoft.com/en-us/windows/win32/intl/code-page-identifiers
+        return 437 # OEM United States
+
+    @apihook("GetClipboardViewer", argc=0)
+    def GetClipboardViewer(self, emu, argv, ctx={}):
+        '''
+        HWND GetClipboardViewer();
+        '''
+        hnd = 0
+
+        desk = self.sessman.get_current_desktop()
+        window = desk.get_desktop_window()
+        hnd = window.get_handle()
+
+        return hnd
+
+    @apihook("GetClipboardOwner", argc=0)
+    def GetClipboardOwner(self, emu, argv, ctx={}):
+        '''
+        HWND GetClipboardOwner();
+        '''
+        hnd = 0
+
+        desk = self.sessman.get_current_desktop()
+        window = desk.get_desktop_window()
+        hnd = window.get_handle()
+
+        return hnd
+
+    @apihook("GetMenuCheckMarkDimensions", argc=0)
+    def GetMenuCheckMarkDimensions(self, emu, argv, ctx={}):
+        '''
+        LONG GetMenuCheckMarkDimensions();
+        '''
+        # >>> ctypes.windll.user32.GetMenuCheckMarkDimensions()
+        # 983055
+        return 983055
+
+    @apihook("GetOpenClipboardWindow", argc=0)
+    def GetOpenClipboardWindow(self, emu, argv, ctx={}):
+        '''
+        HWND GetOpenClipboardWindow();
+        '''
+        hnd = 0
+
+        desk = self.sessman.get_current_desktop()
+        window = desk.get_desktop_window()
+        hnd = window.get_handle()
+
+        return hnd
+
+    @apihook("GetFocus", argc=0)
+    def GetFocus(self, emu, argv, ctx={}):
+        '''
+        HWND GetFocus();
+        '''
+        hnd = 0
+
+        desk = self.sessman.get_current_desktop()
+        window = desk.get_desktop_window()
+        hnd = window.get_handle()
+
+        return hnd
+
+    @apihook("GetCursor", argc=0)
+    def GetCursor(self, emu, argv, ctx={}):
+        '''
+        HCURSOR GetCursor();
+        '''
+        hnd = 0
+
+        desk = self.sessman.get_current_desktop()
+        window = desk.get_desktop_window()
+        hnd = window.get_handle()
+
+        return hnd
+
+    @apihook("GetClipboardSequenceNumber", argc=0)
+    def GetClipboardSequenceNumber(self, emu, argv, ctx={}):
+        '''
+        DWORD GetClipboardSequenceNumber();
+        '''
+        # >>> ctypes.windll.user32.GetClipboardSequenceNumber()
+        # 295
+        return 295
+
+    @apihook("GetCaretBlinkTime", argc=0)
+    def GetCaretBlinkTime(self, emu, argv, ctx={}):
+        '''
+        UINT GetCaretBlinkTime();
+        '''
+        # >>> ctypes.windll.user32.GetCaretBlinkTime()
+        # 530
+        return 530
+
+    @apihook("GetDoubleClickTime", argc=0)
+    def GetDoubleClickTime(self, emu, argv, ctx={}):
+        '''
+        UINT GetDoubleClickTime();
+        '''
+        # >>> ctypes.windll.user32.GetDoubleClickTime()
+        # 500
+        return 500
