@@ -2,7 +2,7 @@
 import re
 import struct
 
-from socket import inet_ntoa, ntohs, htons, ntohl, htonl, inet_aton
+from socket import inet_ntoa, inet_aton, inet_pton, inet_ntop, ntohs, htons, ntohl, htonl
 
 import speakeasy.winenv.arch as _arch
 
@@ -265,24 +265,27 @@ class Ws2_32(api.ApiHandler):
         name = self.read_mem_string(name, 1)
         ptr_hostent = 0
 
-        hostent = 0
         ip = self.netman.name_lookup(name)
 
         if ip:
             hostent = self.wstypes.hostent(emu.get_ptr_size())
-            buflen = len(name)
-            buflen += 8
-            buflen += len(ip)
-            ptr_hostent = self.mem_alloc(buflen, tag='api.struct.HOSTENT')
+            ptr_hostent = self.mem_alloc(hostent.sizeof(), tag='api.struct.HOSTENT')
             hostent.h_name = argv[0]
-            hostent.h_length = len(ip)
-            ip_bytes = inet_aton(ip)
-            ptr_h_addr = self.mem_alloc(len(ip_bytes)*3, tag='api.struct.HOSTENT.h_addr')
 
-            ptr = (ptr_h_addr + self.get_ptr_size())
-            self.mem_write(ptr_h_addr, ptr.to_bytes(self.get_ptr_size(), 'little'))
-            self.mem_write(ptr, ip_bytes)
-            hostent.h_addr_list = ptr_h_addr
+            # List contains no aliases so just the NULL terminator
+            ptr_h_aliases = self.mem_alloc(emu.get_ptr_size(), tag='api.struct.HOSTENT.h_aliases')
+            hostent.h_aliases = ptr_h_aliases
+
+            hostent.h_addrtype = winsock.AF_INET
+            hostent.h_length = 4
+
+            # List contains one addr pointer and the NULL terminator
+            ptr_h_addr_list = self.mem_alloc(emu.get_ptr_size() * 2, tag='api.struct.HOSTENT.h_addr_list')
+            ptr_h_addr_0 = self.mem_alloc(hostent.h_length, tag='api.struct.HOSTENT.h_addr_0')
+            ip_bytes = inet_aton(ip)
+            self.mem_write(ptr_h_addr_0, ip_bytes)
+            self.mem_write(ptr_h_addr_list, ptr_h_addr_0.to_bytes(self.get_ptr_size(), 'little'))
+            hostent.h_addr_list = ptr_h_addr_list
 
             # Write the hostent struct
             self.mem_write(ptr_hostent, self.get_bytes(hostent))
@@ -470,6 +473,64 @@ class Ws2_32(api.ApiHandler):
             self.addr_bufs.update({raddr: buf})
         return buf
 
+    @apihook('inet_ntop', argc=4, ordinal=180)
+    def inet_ntop(self, emu, argv, ctx={}):
+        """
+        PCSTR WSAAPI inet_ntop(
+          [in]  INT        Family,
+          [in]  const VOID *pAddr,
+          [out] PSTR       pStringBuf,
+          [in]  size_t     StringBufSize
+        );
+        """
+        family, pAddr, pStringBuf, StringBufSize = argv
+
+        fam_str = winsock.get_addr_family(family)
+        argv[0] = fam_str
+
+        # TODO: implement case AF_INET6
+        if fam_str == 'AF_INET':
+            ipv4_bytes = self.mem_read(pAddr, 4)
+            argv[1] = int.from_bytes(ipv4_bytes, 'big')
+            try:
+                ipv4_str = inet_ntop(family, ipv4_bytes)
+            except OSError:
+                return 0
+
+            self.write_string(ipv4_str, pStringBuf)
+            return pStringBuf
+
+        return 0
+
+    @apihook('inet_pton', argc=3, ordinal=181)
+    def inet_pton(self, emu, argv, ctx={}):
+        """
+        INT WSAAPI inet_pton(
+          [in]  INT   Family,
+          [in]  PCSTR pszAddrString,
+          [out] PVOID pAddrBuf
+        );
+        """
+
+        family, pszAddrString, pAddrBuf = argv
+
+        fam_str = winsock.get_addr_family(family)
+        argv[0] = fam_str
+
+        # TODO: implement case AF_INET6
+        if fam_str == 'AF_INET':
+            ipv4_str = self.read_string(pszAddrString)
+            argv[1] = ipv4_str
+            try:
+                ipv4_bytes = inet_pton(family, ipv4_str)
+            except OSError:
+                return 0
+
+            self.mem_write(pAddrBuf, ipv4_bytes)
+            return 1
+
+        return 0
+
     @apihook('htonl', argc=1, ordinal=8)
     def htonl(self, emu, argv, ctx={}):
         """
