@@ -8,6 +8,8 @@ NTE_BAD_ALGID = 0x80090008
 SERVICE_WIN32 = 0x30
 
 SERVICE_ACTIVE = 0x1
+SERVICE_INACTIVE = 0x2
+SERVICE_STATE_ALL = 0x3
 
 
 class SERVICE_TABLE_ENTRY(EmuStruct):
